==> aws-cdk-scala-autoscalingplans_3-0.4.0-javadoc.jar: scripts/searchData.js <==
pages = [{"l":"index.html","n":"autoscalingplans","t":"autoscalingplans","d":"","k":"static"},
{"l":"io/burkard/cdk/services/autoscalingplans.html","n":"io.burkard.cdk.services.autoscalingplans","t":"package io.burkard.cdk.services.autoscalingplans","d":"io/burkard/cdk/services/autoscalingplans","k":"package"},
{"l":"io/burkard/cdk/services/autoscalingplans/ApplicationSourceProperty$.html","n":"ApplicationSourceProperty","t":"object ApplicationSourceProperty","d":"io/burkard/cdk/services/autoscalingplans/ApplicationSourceProperty$","k":"object"},
{"l":"io/burkard/cdk/services/autoscalingplans/ApplicationSourceProperty$.html","n":"apply","t":"def apply(tagFilters: Option[List[_]], cloudFormationStackArn: Option[String]): ApplicationSourceProperty","d":"io/burkard/cdk/services/autoscalingplans/ApplicationSourceProperty$","k":"def"},
{"l":"io/burkard/cdk/services/autoscalingplans/CfnScalingPlan$.html","n":"CfnScalingPlan","t":"object CfnScalingPlan","d":"io/burkard/cdk/services/autoscalingplans/CfnScalingPlan$","k":"object"},
{"l":"io/burkard/cdk/services/autoscalingplans/CfnScalingPlan$.html","n":"apply","t":"def apply(internalResourceId: String, applicationSource: ApplicationSourceProperty, scalingInstructions: List[_])(implicit stackCtx: Stack): CfnScalingPlan","d":"io/burkard/cdk/services/autoscalingplans/CfnScalingPlan$","k":"def"},
{"l":"io/burkard/cdk/services/autoscalingplans/CfnScalingPlanProps$.html","n":"CfnScalingPlanProps","t":"object CfnScalingPlanProps","d":"io/burkard/cdk/services/autoscalingplans/CfnScalingPlanProps$","k":"object"},
{"l":"io/burkard/cdk/services/autoscalingplans/CfnScalingPlanProps$.html","n":"apply","t":"def apply(applicationSource: ApplicationSourceProperty, scalingInstructions: List[_]): CfnScalingPlanProps","d":"io/burkard/cdk/services/autoscalingplans/CfnScalingPlanProps$","k":"def"},
{"l":"io/burkard/cdk/services/autoscalingplans/CustomizedLoadMetricSpecificationProperty$.html","n":"CustomizedLoadMetricSpecificationProperty","t":"object CustomizedLoadMetricSpecificationProperty","d":"io/burkard/cdk/services/autoscalingplans/CustomizedLoadMetricSpecificationProperty$","k":"object"},
{"l":"io/burkard/cdk/services/autoscalingplans/CustomizedLoadMetricSpecificationProperty$.html","n":"apply","t":"def apply(statistic: String, metricName: String, namespace: String, dimensions: Option[List[_]], unit: Option[String]): CustomizedLoadMetricSpecificationProperty","d":"io/burkard/cdk/services/autoscalingplans/CustomizedLoadMetricSpecificationProperty$","k":"def"},
{"l":"io/burkard/cdk/services/autoscalingplans/CustomizedScalingMetricSpecificationProperty$.html","n":"CustomizedScalingMetricSpecificationProperty","t":"object CustomizedScalingMetricSpecificationProperty","d":"io/burkard/cdk/services/autoscalingplans/CustomizedScalingMetricSpecificationProperty$","k":"object"},
{"l":"io/burkard/cdk/services/autoscalingplans/CustomizedScalingMetricSpecificationProperty$.html","n":"apply","t":"def apply(statistic: String, metricName: String, namespace: String, dimensions: Option[List[_]], unit: Option[String]): CustomizedScalingMetricSpecificationProperty","d":"io/burkard/cdk/services/autoscalingplans/CustomizedScalingMetricSpecificationProperty$","k":"def"},
{"l":"io/burkard/cdk/services/autoscalingplans/MetricDimensionProperty$.html","n":"MetricDimensionProperty","t":"object MetricDimensionProperty","d":"io/burkard/cdk/services/autoscalingplans/MetricDimensionProperty$","k":"object"},
{"l":"io/burkard/cdk/services/autoscalingplans/MetricDimensionProperty$.html","n":"apply","t":"def apply(name: String, value: String): MetricDimensionProperty","d":"io/burkard/cdk/services/autoscalingplans/MetricDimensionProperty$","k":"def"},
{"l":"io/burkard/cdk/services/autoscalingplans/PredefinedLoadMetricSpecificationProperty$.html","n":"PredefinedLoadMetricSpecificationProperty","t":"object PredefinedLoadMetricSpecificationProperty","d":"io/burkard/cdk/services/autoscalingplans/PredefinedLoadMetricSpecificationProperty$","k":"object"},
{"l":"io/burkard/cdk/services/autoscalingplans/PredefinedLoadMetricSpecificationProperty$.html","n":"apply","t":"def apply(predefinedLoadMetricType: String, resourceLabel: Option[String]): PredefinedLoadMetricSpecificationProperty","d":"io/burkard/cdk/services/autoscalingplans/PredefinedLoadMetricSpecificationProperty$","k":"def"},
{"l":"io/burkard/cdk/services/autoscalingplans/PredefinedScalingMetricSpecificationProperty$.html","n":"PredefinedScalingMetricSpecificationProperty","t":"object PredefinedScalingMetricSpecificationProperty","d":"io/burkard/cdk/services/autoscalingplans/PredefinedScalingMetricSpecificationProperty$","k":"object"},
{"l":"io/burkard/cdk/services/autoscalingplans/PredefinedScalingMetricSpecificationProperty$.html","n":"apply","t":"def apply(predefinedScalingMetricType: String, resourceLabel: Option[String]): PredefinedScalingMetricSpecificationProperty","d":"io/burkard/cdk/services/autoscalingplans/PredefinedScalingMetricSpecificationProperty$","k":"def"},
{"l":"io/burkard/cdk/services/autoscalingplans/ScalingInstructionProperty$.html","n":"ScalingInstructionProperty","t":"object ScalingInstructionProperty","d":"io/burkard/cdk/services/autoscalingplans/ScalingInstructionProperty$","k":"object"},
{"l":"io/burkard/cdk/services/autoscalingplans/ScalingInstructionProperty$.html","n":"apply","t":"def apply(scalableDimension: String, resourceId: String, maxCapacity: Number, serviceNamespace: String, minCapacity: Number, targetTrackingConfigurations: List[_], scalingPolicyUpdateBehavior: Option[String], predictiveScalingMaxCapacityBuffer: Option[Number], customizedLoadMetricSpecification: Option[CustomizedLoadMetricSpecificationProperty], scheduledActionBufferTime: Option[Number], predictiveScalingMode: Option[String], predefinedLoadMetricSpecification: Option[PredefinedLoadMetricSpecificationProperty], disableDynamicScaling: Option[Boolean], predictiveScalingMaxCapacityBehavior: Option[String]): ScalingInstructionProperty","d":"io/burkard/cdk/services/autoscalingplans/ScalingInstructionProperty$","k":"def"},
{"l":"io/burkard/cdk/services/autoscalingplans/TagFilterProperty$.html","n":"TagFilterProperty","t":"object TagFilterProperty","d":"io/burkard/cdk/services/autoscalingplans/TagFilterProperty$","k":"object"},
{"l":"io/burkard/cdk/services/autoscalingplans/TagFilterProperty$.html","n":"apply","t":"def apply(key: String, values: Option[List[String]]): TagFilterProperty","d":"io/burkard/cdk/services/autoscalingplans/TagFilterProperty$","k":"def"},
{"l":"io/burkard/cdk/services/autoscalingplans/TargetTrackingConfigurationProperty$.html","n":"TargetTrackingConfigurationProperty","t":"object TargetTrackingConfigurationProperty","d":"io/burkard/cdk/services/autoscalingplans/TargetTrackingConfigurationProperty$","k":"object"},
{"l":"io/burkard/cdk/services/autoscalingplans/TargetTrackingConfigurationProperty$.html","n":"apply","t":"def apply(targetValue: Number, disableScaleIn: Option[Boolean], predefinedScalingMetricSpecification: Option[PredefinedScalingMetricSpecificationProperty], customizedScalingMetricSpecification: Option[CustomizedScalingMetricSpecificationProperty], scaleOutCooldown: Option[Number], estimatedInstanceWarmup: Option[Number], scaleInCooldown: Option[Number]): TargetTrackingConfigurationProperty","d":"io/burkard/cdk/services/autoscalingplans/TargetTrackingConfigurationProperty$","k":"def"},
{"l":"docs/index.html","n":"autoscalingplans","t":"autoscalingplans","d":"","k":"static"}];

==> aws-cdk-scala-autoscalingplans_3-0.5.0-javadoc.jar: scripts/searchData.js <==
pages = [{"l":"index.html","n":"autoscalingplans","t":"autoscalingplans","d":"","k":"static"},
{"l":"io/burkard/cdk/services/autoscalingplans.html","n":"io.burkard.cdk.services.autoscalingplans","t":"package io.burkard.cdk.services.autoscalingplans","d":"io/burkard/cdk/services/autoscalingplans","k":"package"},
{"l":"io/burkard/cdk/services/autoscalingplans/ApplicationSourceProperty$.html","n":"ApplicationSourceProperty","t":"object ApplicationSourceProperty","d":"io/burkard/cdk/services/autoscalingplans/ApplicationSourceProperty$","k":"object"},
{"l":"io/burkard/cdk/services/autoscalingplans/ApplicationSourceProperty$.html","n":"apply","t":"def apply(cloudFormationStackArn: Option[String], tagFilters: Option[List[_]]): ApplicationSourceProperty","d":"io/burkard/cdk/services/autoscalingplans/ApplicationSourceProperty$","k":"def"},
{"l":"io/burkard/cdk/services/autoscalingplans/CfnScalingPlan$.html","n":"CfnScalingPlan","t":"object CfnScalingPlan","d":"io/burkard/cdk/services/autoscalingplans/CfnScalingPlan$","k":"object"},
{"l":"io/burkard/cdk/services/autoscalingplans/CfnScalingPlan$.html","n":"apply","t":"def apply(internalResourceId: String, scalingInstructions: List[_], applicationSource: ApplicationSourceProperty)(implicit stackCtx: Stack): CfnScalingPlan","d":"io/burkard/cdk/services/autoscalingplans/CfnScalingPlan$","k":"def"},
{"l":"io/burkard/cdk/services/autoscalingplans/CfnScalingPlanProps$.html","n":"CfnScalingPlanProps","t":"object CfnScalingPlanProps","d":"io/burkard/cdk/services/autoscalingplans/CfnScalingPlanProps$","k":"object"},
{"l":"io/burkard/cdk/services/autoscalingplans/CfnScalingPlanProps$.html","n":"apply","t":"def apply(scalingInstructions: List[_], applicationSource: ApplicationSourceProperty): CfnScalingPlanProps","d":"io/burkard/cdk/services/autoscalingplans/CfnScalingPlanProps$","k":"def"},
{"l":"io/burkard/cdk/services/autoscalingplans/CustomizedLoadMetricSpecificationProperty$.html","n":"CustomizedLoadMetricSpecificationProperty","t":"object CustomizedLoadMetricSpecificationProperty","d":"io/burkard/cdk/services/autoscalingplans/CustomizedLoadMetricSpecificationProperty$","k":"object"},
{"l":"io/burkard/cdk/services/autoscalingplans/CustomizedLoadMetricSpecificationProperty$.html","n":"apply","t":"def apply(statistic: String, metricName: String, namespace: String, dimensions: Option[List[_]], unit: Option[String]): CustomizedLoadMetricSpecificationProperty","d":"io/burkard/cdk/services/autoscalingplans/CustomizedLoadMetricSpecificationProperty$","k":"def"},
{"l":"io/burkard/cdk/services/autoscalingplans/CustomizedScalingMetricSpecificationProperty$.html","n":"CustomizedScalingMetricSpecificationProperty","t":"object CustomizedScalingMetricSpecificationProperty","d":"io/burkard/cdk/services/autoscalingplans/CustomizedScalingMetricSpecificationProperty$","k":"object"},
{"l":"io/burkard/cdk/services/autoscalingplans/CustomizedScalingMetricSpecificationProperty$.html","n":"apply","t":"def apply(statistic: String, metricName: String, namespace: String, dimensions: Option[List[_]], unit: Option[String]): CustomizedScalingMetricSpecificationProperty","d":"io/burkard/cdk/services/autoscalingplans/CustomizedScalingMetricSpecificationProperty$","k":"def"},
{"l":"io/burkard/cdk/services/autoscalingplans/MetricDimensionProperty$.html","n":"MetricDimensionProperty","t":"object MetricDimensionProperty","d":"io/burkard/cdk/services/autoscalingplans/MetricDimensionProperty$","k":"object"},
{"l":"io/burkard/cdk/services/autoscalingplans/MetricDimensionProperty$.html","n":"apply","t":"def apply(name: String, value: String): MetricDimensionProperty","d":"io/burkard/cdk/services/autoscalingplans/MetricDimensionProperty$","k":"def"},
{"l":"io/burkard/cdk/services/autoscalingplans/PredefinedLoadMetricSpecificationProperty$.html","n":"PredefinedLoadMetricSpecificationProperty","t":"object PredefinedLoadMetricSpecificationProperty","d":"io/burkard/cdk/services/autoscalingplans/PredefinedLoadMetricSpecificationProperty$","k":"object"},
{"l":"io/burkard/cdk/services/autoscalingplans/PredefinedLoadMetricSpecificationProperty$.html","n":"apply","t":"def apply(predefinedLoadMetricType: String, resourceLabel: Option[String]): PredefinedLoadMetricSpecificationProperty","d":"io/burkard/cdk/services/autoscalingplans/PredefinedLoadMetricSpecificationProperty$","k":"def"},
{"l":"io/burkard/cdk/services/autoscalingplans/PredefinedScalingMetricSpecificationProperty$.html","n":"PredefinedScalingMetricSpecificationProperty","t":"object PredefinedScalingMetricSpecificationProperty","d":"io/burkard/cdk/services/autoscalingplans/PredefinedScalingMetricSpecificationProperty$","k":"object"},
{"l":"io/burkard/cdk/services/autoscalingplans/PredefinedScalingMetricSpecificationProperty$.html","n":"apply","t":"def apply(predefinedScalingMetricType: String, resourceLabel: Option[String]): PredefinedScalingMetricSpecificationProperty","d":"io/burkard/cdk/services/autoscalingplans/PredefinedScalingMetricSpecificationProperty$","k":"def"},
{"l":"io/burkard/cdk/services/autoscalingplans/ScalingInstructionProperty$.html","n":"ScalingInstructionProperty","t":"object ScalingInstructionProperty","d":"io/burkard/cdk/services/autoscalingplans/ScalingInstructionProperty$","k":"object"},
{"l":"io/burkard/cdk/services/autoscalingplans/ScalingInstructionProperty$.html","n":"apply","t":"def apply(scalableDimension: String, resourceId: String, maxCapacity: Number, serviceNamespace: String, minCapacity: Number, targetTrackingConfigurations: List[_], scalingPolicyUpdateBehavior: Option[String], predictiveScalingMaxCapacityBuffer: Option[Number], customizedLoadMetricSpecification: Option[CustomizedLoadMetricSpecificationProperty], scheduledActionBufferTime: Option[Number], predictiveScalingMode: Option[String], predefinedLoadMetricSpecification: Option[PredefinedLoadMetricSpecificationProperty], disableDynamicScaling: Option[Boolean], predictiveScalingMaxCapacityBehavior: Option[String]): ScalingInstructionProperty","d":"io/burkard/cdk/services/autoscalingplans/ScalingInstructionProperty$","k":"def"},
{"l":"io/burkard/cdk/services/autoscalingplans/TagFilterProperty$.html","n":"TagFilterProperty","t":"object TagFilterProperty","d":"io/burkard/cdk/services/autoscalingplans/TagFilterProperty$","k":"object"},
{"l":"io/burkard/cdk/services/autoscalingplans/TagFilterProperty$.html","n":"apply","t":"def apply(key: String, values: Option[List[String]]): TagFilterProperty","d":"io/burkard/cdk/services/autoscalingplans/TagFilterProperty$","k":"def"},
{"l":"io/burkard/cdk/services/autoscalingplans/TargetTrackingConfigurationProperty$.html","n":"TargetTrackingConfigurationProperty","t":"object TargetTrackingConfigurationProperty","d":"io/burkard/cdk/services/autoscalingplans/TargetTrackingConfigurationProperty$","k":"object"},
{"l":"io/burkard/cdk/services/autoscalingplans/TargetTrackingConfigurationProperty$.html","n":"apply","t":"def apply(targetValue: Number, disableScaleIn: Option[Boolean], predefinedScalingMetricSpecification: Option[PredefinedScalingMetricSpecificationProperty], customizedScalingMetricSpecification: Option[CustomizedScalingMetricSpecificationProperty], scaleOutCooldown: Option[Number], estimatedInstanceWarmup: Option[Number], scaleInCooldown: Option[Number]): TargetTrackingConfigurationProperty","d":"io/burkard/cdk/services/autoscalingplans/TargetTrackingConfigurationProperty$","k":"def"},
{"l":"docs/index.html","n":"autoscalingplans","t":"autoscalingplans","d":"","k":"static"}];
